Class CallbackResampler — sudio documentation

# Class CallbackResampler

- Defined in File rateshift.hpp

## Class Documentation

class CallbackResampler

  Public Types

  using callback_t = std::function<std::vector<float>()>

  Public Functions

  CallbackResampler(callback_t callback_func, double ratio, ConverterType converter_type, size_t channels)
  ~CallbackResampler()
  std::vector<float> read(size_t frames)
  void set_starting_ratio(double new_ratio)
  void reset()